package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.ElecStoreH;
import com.ruoyi.ems.model.ElecStoreAnalyze;
import com.ruoyi.ems.model.QueryMeter;

import java.util.List;

/**
 * 储能计量-小时Service接口
 *
 * @author ruoyi
 * @date 2024-08-09
 */
public interface IElecStoreService {
    /**
     * 查询储能计量-小时
     *
     * @param id 储能计量-小时主键
     * @return 储能计量-小时
     */
    ElecStoreH selectHourById(Long id);

    /**
     * 获取日分析
     *
     * @param date 日期
     * @return 日分析
     */
    ElecStoreAnalyze getDayStatistics(String date);

    /**
     * 查询储能计量-小时列表
     *
     * @param elecStoreH 储能计量-小时
     * @return 储能计量-小时集合
     */
    List<ElecStoreH> selectHourList(ElecStoreH elecStoreH);

    ElecStoreH selectStoreHByDataRange(ElecStoreH elecStoreH);

    /**
     * 查询储能计量-日列表
     *
     * @param param 参数
     * @return 储能计量-日集合
     */
    List<ElecStoreH> selectDayList(QueryMeter param);

    /**
     * 新增储能计量-小时
     *
     * @param elecStoreH 储能计量-小时
     * @return 结果
     */
    int insertHour(ElecStoreH elecStoreH);

    /**
     * 修改储能计量-小时
     *
     * @param elecStoreH 储能计量-小时
     * @return 结果
     */
    int updateHour(ElecStoreH elecStoreH);

    /**
     * 批量删除储能计量-小时
     *
     * @param ids 需要删除的储能计量-小时主键集合
     * @return 结果
     */
    int deleteHourByIds(Long[] ids);

    /**
     * 删除储能计量-小时信息
     *
     * @param id 储能计量-小时主键
     * @return 结果
     */
    int deleteHourById(Long id);
}
